==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/dochazka/zaznamzpracovanedochazky.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Dochazka;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use RonPortal\PracovniPomer;
use RonPortal\RonPortalSettings;

/**
 * Class ZaznamZpracovaneDochazky
 * Zaznam zpracovane dochazky (interval)
 */
class ZaznamZpracovaneDochazky
{
    var $datumCasPocatku;
    var $datumCasUkonceni;
    var $den;

    var $casOd;
    var $casDo;
    // zobrazeny cas od-do (u zaznamu pres pulnoc muze byt jiny nez puvodni!)
    var $upravaOd;
    var $upravaDo;
    // zobrazeny upraveny cas od-do

    var $textCasOd;
    var $textCasDo; // zobrazovany text - podle $upravaDo, muze byt i 24:00

    var $smena;

    var $kodOperace;
    var $popisOperace;
    var $poznamka;
    var $rozdeleni;

    var $zkratkaOperace; // zkratka operace pro planovani

    var $barva;
    var $editovano;
    var $hint;
    var $textDelka;

    var $poPulnoci; // priznak, ze se jedna jen o "zbytek" zaznamu po pulnoci (pro graficke zobrazeni)


    /**
     * Vytvori kopii zaznamu, ale posune cas zacatku na pulnoc, takze zustane jen cast po pulnoci
     * @return ZaznamZpracovaneDochazky
     */
    function kopiePoPulnoci()
    {
        $result = clone $this;
        $result ->poPulnoci = true;

        $zacatekDne2 = DateUtils::startOfTheDay($result ->datumCasUkonceni); // pomocna promenna pro zaznamy pres pulnoc

        // posune zacatek zaznamu na pulnoc
        if ($result ->casOd < $zacatekDne2) $result ->casOd = $zacatekDne2;
        if ($result ->upravaOd < $zacatekDne2) $result ->upravaOd = $zacatekDne2;
        if ($result ->upravaDo < $zacatekDne2) $result ->upravaDo = $zacatekDne2;

        return $result;
    }


    /**
     * @param Database $database
     * @param array $zaznam
     */
    function nactiPodleRadku($database, $zaznam)
    {
        $this ->poPulnoci = false; // $poPulnoci;

        $this ->datumCasPocatku = $database ->stringToTimestamp($zaznam[0]);
        $this ->datumCasUkonceni = $database ->stringToTimestamp($zaznam[2]);
        $this ->den = $database ->stringToTimestamp($zaznam[7]);

        $this ->casOd = $this ->datumCasPocatku;
        $this ->casDo = $this ->datumCasUkonceni;

        $this ->upravaOd = $this ->datumCasPocatku - (int)round(86400 * $zaznam[3]);
        $this ->upravaDo = $this ->datumCasUkonceni + (int)round(86400 * $zaznam[4]);

        $this ->kodOperace = $zaznam[8];
        $this ->popisOperace = $zaznam[1];

        $this ->zkratkaOperace = $zaznam[9];

        $this ->barva = GuiUtils::getHtmlColor($zaznam[6]);
        if ($zaznam[5]) $this ->editovano = 1;

        $this ->textCasOd = date('G:i', $this ->upravaOd);
        $this ->textDelka = StringUtils::format('minuty', ($this ->upravaDo - $this ->upravaOd) / 60);

        $zacatekDne2 = DateUtils::startOfTheDay($this ->datumCasUkonceni); // pomocna promenna pro zaznamy pres pulnoc

        $this ->textCasDo = ($this ->upravaDo == $zacatekDne2  &&  $this ->upravaDo > $this ->datumCasPocatku)
            ? '24:00'
            : date('G:i', $this ->upravaDo);

        $this ->hint = $this ->textCasOd . ' - ' . $this ->textCasDo . ' ' . $this ->popisOperace . ' (' . $this ->textDelka . ')';

//        if ($poPulnoci) {
//            // posune zacatek zaznamu na pulnoc
//            if ($this ->f_casod < $zacatekDne2) $this ->f_casod = $zacatekDne2;
//            if ($this ->f_upravaod < $zacatekDne2) $this ->f_upravaod = $zacatekDne2;
//            if ($this ->f_upravado < $zacatekDne2) $this ->f_upravado = $zacatekDne2;
//        }

        $this ->poznamka = $zaznam[10];
        $this ->rozdeleni = isset($zaznam[11]) ? $zaznam[11] : null;
    }


    /**
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $nacistPoznamky
     * @return ZaznamZpracovaneDochazky[]
     */
    static function nactiOperaceDochazkyZDB($database, $pp, $datumOd, $datumDo, $nacistPoznamky)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT Dochazka.DatumCasPocatku, OperaceDochazky.Popis, Dochazka.DatumCasUkonceni, ' . // 0 - 2
            ' Dochazka.DeltaPred, Dochazka.DeltaZa, Dochazka.Zpracoval, OperaceDochazky.BarvaProVykresleni, ' . // 3 - 6
            ' Dochazka.Den, Dochazka.Operace, OperaceDochazky.ZkratkaProPlanovani, ' . // 7..9
            ( $nacistPoznamky ? 'PoznamkaDochazky.Poznamka ' : "'' AS Poznamka "); //  10

        if ( RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) $sql .= ', RozliseniDochazky.KodRozdeleni'; // (11)

        $sql .=
            ' FROM Dochazka INNER JOIN OperaceDochazky
                       ON Dochazka.Operace = OperaceDochazky.Kod' .
            ' LEFT OUTER JOIN PoznamkaDochazky ' .
            '   ON PoznamkaDochazky.RC = Dochazka.RC ' .
            '  AND PoznamkaDochazky.OsobniCislo = Dochazka.OsobniCislo ' .
            '  AND PoznamkaDochazky.DatumNastupu = Dochazka.DatumNastupu ' .
            '  AND PoznamkaDochazky.DatumCasPocatku = Dochazka.DatumCasPocatku ';

        if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI))
            $sql .=
                ' LEFT OUTER JOIN RozliseniDochazky ON ( ' .
                ' RozliseniDochazky.RC = Dochazka.RC ' .
                ' AND RozliseniDochazky.OsobniCislo = Dochazka.OsobniCislo ' .
                ' AND RozliseniDochazky.DatumNastupu = Dochazka.DatumNastupu ' .
                ' AND RozliseniDochazky.DatumCasPocatku = Dochazka.DatumCasPocatku ' .
                ' AND RozliseniDochazky.KodTypuRozdeleni = ' . RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI) . ') ';


        $sql .=
            ' WHERE Dochazka.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND Dochazka.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND Dochazka.DatumNastupu = ' . $params ->addParameter($database ->dateToParam($pp ->datumNastupu)) .
            ' AND Dochazka.Den >= ' . $params ->addParameter( $database ->dateToParam(DateUtils::incDay($datumOd, -1)) ) .
            ' AND Dochazka.Den <= ' . $params ->addParameter( $database ->dateToParam(DateUtils::incDay($datumDo, 1)) ) . // nacita o den vice kvuli smenam na prelomu mesice
            ' ORDER BY Dochazka.DatumCasPocatku';

        MessageManager::addDebugLog('Dochazka: ' . $sql);
        $cursor = $database ->getSqlResult($sql, $params);

        $result = [];
        while ($row = $cursor ->fetch()) {
            $zaznam = new ZaznamZpracovaneDochazky();
            $zaznam ->nactiPodleRadku($database, $row);

            $result[] = $zaznam;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * Vraci retezec s popisem zaznamu podle zadaneho formatu
     * @param string $format
     * @return string
     */
    function format($format)
    {
        $text = str_replace('%KOD%', StringUtils::htmlTextConvert($this->kodOperace), $format);
        $text = str_replace('%POPIS%', StringUtils::htmlTextConvert($this->popisOperace), $text);
        $text = str_replace('%ZKRATKA%', StringUtils::htmlTextConvert($this->zkratkaOperace), $text);

        return $text;
    }


    /**
     * Vraci html text pro graficke zobrazeni zaznamu
     * @param int $width
     * @param string $textFormat
     * @param string $htmlParams
     * @return string
     */
    function htmlGraficka($width, $textFormat = '', $htmlParams = '')
    {
//        $len = 86400;
//        $len = DateUtils::endOfTheDay($this ->casOd) - DateUtils::startOfTheDay($this ->casOd);
        //$left = (int)(DateUtils::timeOf($this ->casOd) * $width / 86400);
        $left = ((int)(10000 * DateUtils::timeOf($this ->casOd) / 86400)) / 100;


        $casDo = ($this ->casDo > DateUtils::endOfTheDay($this ->casOd))
            ? DateUtils::endOfTheDay($this ->casOd) // pokud presahuje do dalsiho dne, zobrazi jen cast z aktualniho dne
            : $this ->casDo;

        $w = ((int)(10000 * ($casDo - $this ->casOd) / 86400)) / 100;

        if ($w < 100 / $width) $w = 200 / $width; // minimalni sirka 2px

        $style = "left: {$left}%; width: {$w}%; background-color: {$this ->barva};";
        $classname = 'grafickadochazka';
        if ($this ->editovano) $classname .= ' grafickaeditovana';

        $result =
            '<div class="' . $classname . '" style="' . $style . '" title="' . StringUtils::htmlTextConvert($this ->hint) . '" ' . $htmlParams . '>';

        if ($this ->upravaOd > $this ->casOd  &&  $casDo > $this ->casOd) {
            // zoubek na zacatku
            $w2 = ((int)(10000 * ($this ->upravaOd - $this ->casOd) / ($casDo - $this ->casOd))) / 100;
            $result .= "<div class='graficka_delta' style='left: 0; width: {$w2}%'></div>";
        }

        // zoubek na konci
        if ($this ->upravaDo < $casDo  &&  $casDo > $this ->casOd) {
            // zoubek na konci
            $w2 = ((int)(10000 * ($casDo - $this ->upravaDo) / ($casDo - $this ->casOd))) / 100;
            $result .= "<div class='graficka_delta' style='right: 0; width: {$w2}%'></div>";
        }

        if ($textFormat) {
            $text = $this ->format($textFormat);

            if ($text) $result .= "<span class='graficka_popis' style='background-color: {$this ->barva};'>$text</span>";
        }

        $result .= '</div>';

        return $result;
    }


    /**
     * Zjisti, ktera operace v danem seznamu zpracovane dochazky zabira nejdelsi cas a vraci prvni zaznam s touto operaci
     * @param ZaznamZpracovaneDochazky[] $seznam
     * @return ZaznamZpracovaneDochazky
     */
    public static function vratNejdelsiOperaci($seznam)
    {
        $pomArray = [];

        foreach ($seznam as $zaznamDochazky) {
            if (!isset($pomArray[$zaznamDochazky ->kodOperace])) {
                $pomArray[$zaznamDochazky ->kodOperace] = [
                    'zaznam' => $zaznamDochazky,
                    'soucet' => $zaznamDochazky ->upravaDo - $zaznamDochazky ->upravaOd
                ];
            } else {
                $pomArray[$zaznamDochazky->kodOperace]['soucet'] += $zaznamDochazky ->upravaDo - $zaznamDochazky ->upravaOd;
            }
        }

        $longest = null;
        foreach ($pomArray as $pom) {
            if ($longest) {
                if ($pom['soucet'] > $longest['soucet']) {
                    $longest = $pom;
                }
            } else {
                $longest = $pom;
            }
        }

        if ($longest) return $longest['zaznam'];
        return null;
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/dochazka/zaznamzpracovanedochazky.php <==
<?php
/**
 * stanislav.elbl, 27.02.2021
 */

namespace RonPortal\Dochazka;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\GuiUtils;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\PracovniPomer;
use RonPortal\RonPortalSettings;

/**
 * Class ZaznamZpracovaneDochazky
 * Zaznam zpracovane dochazky (interval)
 */
class ZaznamZpracovaneDochazky
{
    public $datumCasPocatku;
    public $datumCasUkonceni;
    public $den;

    public $casOd;
    public $casDo;

    public $deltaPred;
    public $deltaZa;

    // zobrazeny cas od-do (u zaznamu pres pulnoc muze byt jiny nez puvodni!). Vypocita se podle casu a delta
    public $upravaOd;
    public $upravaDo;

    // zobrazeny upraveny cas od-do
    public $textCasOd;
    public $textCasDo; // zobrazovany text - podle $upravaDo, muze byt i 24:00

    public $smena;

    public $kodOperace;
    public $popisOperace;
    public $poznamka;
    public $rozdeleni;

    /** @var string     Zkratka operace pro planovani */
    public $zkratkaOperace;

    public $barva;
    public $editovano;
    public $hint;
    public $textDelka;

    /** @var bool       Priznak, ze se jedna jen o "zbytek" zaznamu po pulnoci (pro graficke zobrazeni)  */
    public $poPulnoci;


    /**
     * Vytvori kopii zaznamu, ale posune cas zacatku na zacatek zadaneho dne, takze zustane jen cast po pulnoci
     * @return ZaznamZpracovaneDochazky
     */
    function kopiePoPulnoci($datum)
    {
        $result = clone $this;
        $result ->poPulnoci = true;

        $zacatekDne2 = $datum ?: DateUtils::startOfTheDay($result ->datumCasUkonceni); // pomocna promenna pro zaznamy pres pulnoc

        // posune zacatek zaznamu na pulnoc
        if ($result ->casOd < $zacatekDne2) {
            $result ->casOd = $zacatekDne2;
        }
        if ($result ->upravaOd < $zacatekDne2) {
            $result ->upravaOd = $zacatekDne2;
        }
        if ($result ->upravaDo < $zacatekDne2) {
            $result ->upravaDo = $zacatekDne2;
        }

        return $result;
    }


    /**
     * @param Database $database
     * @param array $row
     */
    private function nactiPodleRadku($database, $row)
    {
        $this ->poPulnoci = false; // $poPulnoci;

        $this ->datumCasPocatku = $database ->stringToTimestamp($row[0]);
        $this ->datumCasUkonceni = $database ->stringToTimestamp($row[2]);
        $this ->den = $database ->stringToTimestamp($row[7]);

        $this ->casOd = $this ->datumCasPocatku;
        $this ->casDo = $this ->datumCasUkonceni;

        $this ->deltaPred = isset($row[3]) ? (double)$row[3] : null;
        $this ->deltaZa = isset($row[4]) ? (double)$row[4] : null;

        $this ->upravaOd = $this ->datumCasPocatku - (int)round(86400 * $row[3]);
        $this ->upravaDo = $this ->datumCasUkonceni + (int)round(86400 * $row[4]);

        $this ->kodOperace = $row[8];
        $this ->popisOperace = TextManager::_('db_operacedochazky_popis_' . $row[8], $row[1]);

        $this ->zkratkaOperace = $row[9];

        $this ->barva = GuiUtils::getHtmlColor($row[6]);
        if ($row[5]) {
            $this ->editovano = 1;
        }

        $this ->textCasOd = date('G:i', $this ->upravaOd);
        $this ->textDelka = StringUtils::format('minuty', ($this ->upravaDo - $this ->upravaOd) / 60);

        $zacatekDne2 = DateUtils::startOfTheDay($this ->datumCasUkonceni); // pomocna promenna pro zaznamy pres pulnoc

        $this ->textCasDo = ($this ->upravaDo == $zacatekDne2  &&  $this ->upravaDo > $this ->datumCasPocatku)
            ? '24:00'
            : date('G:i', $this ->upravaDo);

        $this ->hint = $this ->textCasOd . ' - ' . $this ->textCasDo . ' ' . $this ->popisOperace . ' (' . $this ->textDelka . ')';

//        if ($poPulnoci) {
//            // posune zacatek zaznamu na pulnoc
//            if ($this ->f_casod < $zacatekDne2) $this ->f_casod = $zacatekDne2;
//            if ($this ->f_upravaod < $zacatekDne2) $this ->f_upravaod = $zacatekDne2;
//            if ($this ->f_upravado < $zacatekDne2) $this ->f_upravado = $zacatekDne2;
//        }

        $this ->smena = $row[10];
        $this ->poznamka = $row[11];
        $this ->rozdeleni = isset($row[12])
            ? $row[12]
            : null;
    }


    /**
     * @param Database $database
     * @param PracovniPomer $pp
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $nacistPoznamky
     * @return ZaznamZpracovaneDochazky[]
     */
    static function nactiOperaceDochazkyZDB($database, $pp, $datumOd, $datumDo, $nacistPoznamky)
    {
        $params = $database ->createParameters();

        $sql =
            'SELECT Dochazka.DatumCasPocatku, OperaceDochazky.Popis, Dochazka.DatumCasUkonceni, ' . // 0 - 2
            ' Dochazka.DeltaPred, Dochazka.DeltaZa, Dochazka.Zpracoval, OperaceDochazky.BarvaProVykresleni, ' . // 3 - 6
            ' Dochazka.Den, Dochazka.Operace, OperaceDochazky.ZkratkaProPlanovani, ' . // 7..9
            ' Dochazka.Smena, ' . // 10
            ( $nacistPoznamky ? 'PoznamkaDochazky.Poznamka ' : "'' AS Poznamka "); //  11

        if ( RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) {
            $sql .= ', RozliseniDochazky.KodRozdeleni'; // (12)
        }

        $sql .=
            ' FROM Dochazka INNER JOIN OperaceDochazky
                       ON Dochazka.Operace = OperaceDochazky.Kod' .
            ' LEFT OUTER JOIN PoznamkaDochazky ' .
            '   ON PoznamkaDochazky.RC = Dochazka.RC ' .
            '  AND PoznamkaDochazky.OsobniCislo = Dochazka.OsobniCislo ' .
            '  AND PoznamkaDochazky.DatumNastupu = Dochazka.DatumNastupu ' .
            '  AND PoznamkaDochazky.DatumCasPocatku = Dochazka.DatumCasPocatku ';

        if (RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI)) {
            $sql .=
                ' LEFT OUTER JOIN RozliseniDochazky ON ( ' .
                ' RozliseniDochazky.RC = Dochazka.RC ' .
                ' AND RozliseniDochazky.OsobniCislo = Dochazka.OsobniCislo ' .
                ' AND RozliseniDochazky.DatumNastupu = Dochazka.DatumNastupu ' .
                ' AND RozliseniDochazky.DatumCasPocatku = Dochazka.DatumCasPocatku ' .
                ' AND RozliseniDochazky.KodTypuRozdeleni = ' . RonPortalSettings::getIntValue(RonPortalSettings::EDITACE_TYP_ROZDELENI) . ') ';
        }


        $sql .=
            ' WHERE Dochazka.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND Dochazka.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND Dochazka.DatumNastupu = ' . $params ->addParameter($database ->dateToParam($pp ->datumNastupu)) .
            ' AND Dochazka.Den >= ' . $params ->addParameter( $database ->dateToParam($datumOd) ) .
            ' AND Dochazka.Den <= ' . $params ->addParameter( $database ->dateToParam($datumDo) ) .
            ' ORDER BY Dochazka.DatumCasPocatku';

        MessageManager::addDebugLog('Dochazka: ' . $sql);
        $cursor = $database ->getSqlResult($sql, $params);

        $result = [];
        while ($row = $cursor ->fetch()) {
            $zaznam = new ZaznamZpracovaneDochazky();
            $zaznam ->nactiPodleRadku($database, $row);

            $result[] = $zaznam;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * Vraci retezec s popisem zaznamu podle zadaneho formatu
     * @param string $format
     * @return string
     */
    function format($format)
    {
        return
            str_replace(
                ['%KOD%', '%POPIS%', '%ZKRATKA%'],
                [StringUtils::htmlTextConvert($this->kodOperace), StringUtils::htmlTextConvert($this->popisOperace), StringUtils::htmlTextConvert($this->zkratkaOperace)],
                $format);
    }


    /**
     * Vraci html text pro graficke zobrazeni zaznamu
     * @param int $width
     * @param string $textFormat
     * @param string $htmlParams
     * @return string
     */
    function htmlGraficka($width, $textFormat = '', $htmlParams = '')
    {
//        $len = 86400;
//        $len = DateUtils::endOfTheDay($this ->casOd) - DateUtils::startOfTheDay($this ->casOd);
        //$left = (int)(DateUtils::timeOf($this ->casOd) * $width / 86400);
        $left = ((int)(10000 * DateUtils::timeOf($this ->casOd) / 86400)) / 100;


        $casDo = ($this ->casDo > DateUtils::endOfTheDay($this ->casOd))
            ? DateUtils::endOfTheDay($this ->casOd) // pokud presahuje do dalsiho dne, zobrazi jen cast z aktualniho dne
            : $this ->casDo;

        $w = ((int)(10000 * ($casDo - $this ->casOd) / 86400)) / 100;

        if ($w < 100 / $width) {
            // minimalni sirka 2px
            $w = 200 / $width;
        }

        $style = "left: {$left}%; width: {$w}%; background-color: {$this ->barva};";
        $classname =
            'grafickadochazka' .
            ($this ->editovano ? ' grafickaeditovana' : '');

        $result =
            '<div class="' . $classname . '" style="' . $style . '" title="' . StringUtils::htmlTextConvert($this ->hint) . '" ' . $htmlParams . '>';

        if ($this ->upravaOd > $this ->casOd  &&  $casDo > $this ->casOd) {
            // zoubek na zacatku
            $w2 = ((int)(10000 * ($this ->upravaOd - $this ->casOd) / ($casDo - $this ->casOd))) / 100;
            $result .=
                "<div class='graficka_delta' style='left: 0; width: {$w2}%'></div>";
        }

        // zoubek na konci
        if ($this ->upravaDo < $casDo  &&  $casDo > $this ->casOd) {
            // zoubek na konci
            $w2 = ((int)(10000 * ($casDo - $this ->upravaDo) / ($casDo - $this ->casOd))) / 100;
            $result .= "<div class='graficka_delta' style='right: 0; width: {$w2}%'></div>";
        }

        if ($textFormat) {
            $text = $this ->format($textFormat);

            if ($text) {
                $result .= "<span class='graficka_popis' style='background-color: {$this ->barva};'>$text</span>";
            }
        }

        $result .= '</div>';

        return $result;
    }


    /**
     * Zjisti, ktera operace v danem seznamu zpracovane dochazky zabira nejdelsi cas a vraci prvni zaznam s touto operaci
     * @param ZaznamZpracovaneDochazky[] $seznam
     * @return ZaznamZpracovaneDochazky
     */
    public static function vratNejdelsiOperaci($seznam)
    {
        $pomArray = [];

        foreach ($seznam as $zaznamDochazky) {
            if (!isset($pomArray[$zaznamDochazky ->kodOperace])) {
                $pomArray[$zaznamDochazky ->kodOperace] = [
                    'zaznam' => $zaznamDochazky,
                    'soucet' => $zaznamDochazky ->upravaDo - $zaznamDochazky ->upravaOd
                ];
            } else {
                $pomArray[$zaznamDochazky->kodOperace]['soucet'] += $zaznamDochazky ->upravaDo - $zaznamDochazky ->upravaOd;
            }
        }

        $longest = null;
        foreach ($pomArray as $pom) {
            if ($longest) {
                if ($pom['soucet'] > $longest['soucet']) {
                    $longest = $pom;
                }
            } else {
                $longest = $pom;
            }
        }

        if ($longest) {
            return $longest['zaznam'];
        }

        return null;
    }
}
